@@ -1,11 +1,11 @@
 import setuptools
-with open('Tcl/README.md', 'r') as rd:
-	read = rd.read()
+with open('Tcl/README.md', 'r') as fh:
+	read = fh.read()
 
 
 setuptools.setup(
 	name = "Tcl",
-	version = "0.1",
+	version = "0.2",
 
 
 	author = "Repl.it Developer",
@@ -15,7 +15,7 @@ setuptools.setup(
 	description = "A coding language used for Graphical user interface",
 
 
-	ld = rd,
+	long_description = read,
 	url = "https://github.com/SCORPIA-oss/Tcl-repo",
 
 
